==> zio-aws-lightsail_2.12-5.19.7.3-sources.jar: zio/aws/lightsail/model/EndpointRequest.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class EndpointRequest(
    containerName: String,
    containerPort: Integer,
    healthCheck: Optional[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.EndpointRequest = {
    import EndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.EndpointRequest
      .builder()
      .containerName(containerName: java.lang.String)
      .containerPort(containerPort: java.lang.Integer)
      .optionallyWith(healthCheck.map(value => value.buildAwsValue()))(
        _.healthCheck
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.EndpointRequest.ReadOnly =
    zio.aws.lightsail.model.EndpointRequest.wrap(buildAwsValue())
}
object EndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.EndpointRequest =
      zio.aws.lightsail.model.EndpointRequest(
        containerName,
        containerPort,
        healthCheck.map(value => value.asEditable)
      )
    def containerName: String
    def containerPort: Integer
    def healthCheck: Optional[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ]
    def getContainerName: ZIO[Any, Nothing, String] = ZIO.succeed(containerName)
    def getContainerPort: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(containerPort)
    def getHealthCheck: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ] = AwsError.unwrapOptionField("healthCheck", healthCheck)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ) extends zio.aws.lightsail.model.EndpointRequest.ReadOnly {
    override val containerName: String = impl.containerName(): String
    override val containerPort: Integer = impl.containerPort(): Integer
    override val healthCheck: Optional[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.healthCheck())
      .map(value =>
        zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ): zio.aws.lightsail.model.EndpointRequest.ReadOnly = new Wrapper(impl)
}

==> zio-aws-lightsail_2.13-5.17.104.4-sources.jar: zio/aws/lightsail/model/EndpointRequest.scala <==
package zio.aws.lightsail.model
import zio.aws.lightsail.model.primitives.Integer
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class EndpointRequest(
    containerName: String,
    containerPort: Integer,
    healthCheck: Option[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.lightsail.model.EndpointRequest = {
    import EndpointRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.lightsail.model.EndpointRequest
      .builder()
      .containerName(containerName: java.lang.String)
      .containerPort(Integer.unwrap(containerPort): java.lang.Integer)
      .optionallyWith(healthCheck.map(value => value.buildAwsValue()))(
        _.healthCheck
      )
      .build()
  }
  def asReadOnly: zio.aws.lightsail.model.EndpointRequest.ReadOnly =
    zio.aws.lightsail.model.EndpointRequest.wrap(buildAwsValue())
}
object EndpointRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.lightsail.model.EndpointRequest =
      zio.aws.lightsail.model.EndpointRequest(
        containerName,
        containerPort,
        healthCheck.map(value => value.asEditable)
      )
    def containerName: String
    def containerPort: Integer
    def healthCheck: Option[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ]
    def getContainerName: ZIO[Any, Nothing, String] = ZIO.succeed(containerName)
    def getContainerPort: ZIO[Any, Nothing, Integer] =
      ZIO.succeed(containerPort)
    def getHealthCheck: ZIO[
      Any,
      AwsError,
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ] = AwsError.unwrapOptionField("healthCheck", healthCheck)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ) extends zio.aws.lightsail.model.EndpointRequest.ReadOnly {
    override val containerName: String = impl.containerName(): String
    override val containerPort: Integer =
      zio.aws.lightsail.model.primitives.Integer(impl.containerPort())
    override val healthCheck: Option[
      zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.ReadOnly
    ] = scala
      .Option(impl.healthCheck())
      .map(value =>
        zio.aws.lightsail.model.ContainerServiceHealthCheckConfig.wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.lightsail.model.EndpointRequest
  ): zio.aws.lightsail.model.EndpointRequest.ReadOnly = new Wrapper(impl)
}
